This function will operate with ggplot objects to use the squba
standard colors/color palettes to add fill to graphs
Arguments
- palette
string || defaults to
mainThe name of the palette as it appears in
squba_palettes_standard- discrete
boolean || defaults to
TRUEA boolean indicating whether the fill aesthetic is discrete or not
- reverse
boolean || defaults to
FALSEA boolean indicating whether the palette should be reversed
- ...
Any additional arguments passed to ggplot2::discrete_scale or ggplot2::scale_fill_gradientn, used respectively when discrete is TRUE or FALSE